-----------------------------------------------------------------------------

if not AceLibrary:HasInstance("FuBarPlugin-2.0") then return end

-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AssessmentFu")

L:RegisterTranslations("enUS", function() return {
	["Assessment"] = true,
    ["Fubar Options"] = true,
    ["FuBar options."] = true,
	["Click to reset fight data."] = true,
	["Shift-Click to open configuration."] = "|cffeda55fShift-Click|r to open configuration. ",

	["Update Interval"] = true,
	["Time in seconds before updating FuBar text."] = true,

	["Text Tag"] = true,
	["FuBar Text Tag."] = true,
	["Any Tag String."] = true,

	["Fight Data"] = true,
	["Select which fight data to use for tag display."] = true,
	["Total Data"] = true,
	["Current Fight"] = true,
	["Previous Fight"] = true,
} end)

-----------------------------------------------------------------------------

local AssessmentFu = AceLibrary("AceAddon-2.0"):new("FuBarPlugin-2.0", "AceEvent-2.0", "AceDB-2.0")
AssessmentFu:RegisterDB("AssessmentFuDB")
AssessmentFu.title = "Assessment"
AssessmentFu.name = "FuBar - Assessment"
AssessmentFu.hasIcon = "Interface\\Icons\\INV_Misc_StoneTablet_01.jpg"	-- Placeholder
AssessmentFu.blizzardTooltip = true
AssessmentFu.defaultPosition = 'LEFT'
AssessmentFu.hideWithoutStandby = true
AssessmentFu.independentProfile = true
AssessmentFu.hasNoColor = true
 
-----------------------------------------------------------------------------

local tagData =
{
	key = UnitName("player")
}
local textMethod

-----------------------------------------------------------------------------

AssessmentFu:RegisterDefaults('profile', 
	{
		updateInterval = 0.5,
		fightIndex = 1,
		textTag	= "Assessment",
	}
)

AssessmentFu.OnMenuRequest = Assessment.Options

local fuBarArgs = AceLibrary("FuBarPlugin-2.0"):GetAceOptionsDataTable(AssessmentFu)
if not AssessmentFu.OnMenuRequest.args.fubar then
	AssessmentFu.OnMenuRequest.args.extrasSpacer =
	{
		type = 'header',
		order = 90,
	}
	
	AssessmentFu.OnMenuRequest.args.fubar = 
	{
		type = "group",
		name = L["Fubar Options"],
		desc = L["FuBar options."],
		args = fuBarArgs,
		order = 100,
	}
end

fuBarArgs.updateRate =
{
	type	= "range",
	name	= L["Update Interval"],
	desc	= L["Time in seconds before updating FuBar text."],
	min		= 0.05,
	max		= 2,
	step	= 0.05,
	get		= function() return AssessmentFu.db.profile.updateInterval end,
	set		= function(v) AssessmentFu.db.profile.updateInterval = v AssessmentFu:ScheduleRepeatingEvent("AssessmentFu:Update", AssessmentFu.Update, v, AssessmentFu) end,
	order	= 1
}

fuBarArgs.textTag =
{
	type	= "text",
	name	= L["Text Tag"],
	desc	= L["FuBar Text Tag."],
	get		= function() return AssessmentFu.db.profile.textTag end,
	set		= function(v) AssessmentFu.db.profile.textTag = v textMethod = Assessment:CompileTag(v, "string").method AssessmentFu:UpdateText() end,
	usage	= L["Any Tag String."],
	order	= 2,
}

fuBarArgs.fightData =
{
	type = "text",
	name = L["Fight Data"],
	desc = L["Select which fight data to use for tag display."],
	get  = function() return tostring(AssessmentFu.db.profile.fightIndex) end,
	set	 = function(v) AssessmentFu.db.profile.fightIndex = tonumber(v) AssessmentFu:UpdateText() end,
	validate = { ["0"] = L["Total Data"], ["1"] = L["Current Fight"], ["2"] = L["Previous Fight"] },
}

-----------------------------------------------------------------------------

function AssessmentFu:OnEnable()
	textMethod = Assessment:CompileTag(self.db.profile.textTag, "string").method
	self:ScheduleRepeatingEvent("AssessmentFu:Update", self.Update, self.db.profile.updateInterval, self)
end

function AssessmentFu:Update()
	self:UpdateText()
end

function AssessmentFu:OnTextUpdate()
	tagData.fightData = Assessment:GetFightData(self.db.profile.fightIndex)
	self:SetText(textMethod(tagData))
end

function AssessmentFu:OnTooltipUpdate()
	GameTooltip:AddLine(L["Assessment"])
	GameTooltip:AddLine(" ")
	GameTooltip:AddLine(L["Click to reset fight data."])

	if Assessment.Options.args.waterfall then
		GameTooltip:AddLine(L["Shift-Click to open configuration."], 0.2, 1, 0.2)
	end
end

function AssessmentFu:OnClick()
	if Assessment.Options.args.waterfall and IsShiftKeyDown() then
		GameTooltip:Hide()
		Assessment.Options.args.waterfall.func()
		return
	end

	Assessment:ResetFightData()

	self:UpdateTooltip()
end

-----------------------------------------------------------------------------
